==> qtjambi-qt3drender-6.2.1-sources.jar: io/qt/qt3d/render/QFrontFace.java <==
package io.qt.qt3d.render;


/**
 * <p>Defines front and back facing polygons</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html">Qt3DRender::QFrontFace</a></p>
 */
public class QFrontFace extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrontFace.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#WindingDirection-enum">Qt3DRender::QFrontFace::WindingDirection</a></p>
     */
    public enum WindingDirection implements io.qt.QtEnumerator {
        ClockWise(2304),
        CounterClockWise(2305);

        private WindingDirection(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static WindingDirection resolve(int value) {
            switch (value) {
            case 2304: return ClockWise;
            case 2305: return CounterClockWise;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#direction-prop">Qt3DRender::QFrontFace::directionChanged(Qt3DRender::QFrontFace::WindingDirection)</a></p>
     */
    @io.qt.QtPropertyNotify(name="direction")
    public final Signal1<io.qt.qt3d.render.QFrontFace.WindingDirection> directionChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QFrontFace(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrontFace() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#QFrontFace">Qt3DRender::QFrontFace::QFrontFace(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QFrontFace(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrontFace instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#direction-prop">Qt3DRender::QFrontFace::direction()const</a></p>
     */
    @io.qt.QtPropertyReader(name="direction")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QFrontFace.WindingDirection direction(){
        return io.qt.qt3d.render.QFrontFace.WindingDirection.resolve(direction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int direction_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#direction-prop">Qt3DRender::QFrontFace::setDirection(Qt3DRender::QFrontFace::WindingDirection)</a></p>
     */
    @io.qt.QtPropertyWriter(name="direction")
    public final void setDirection(io.qt.qt3d.render.QFrontFace.WindingDirection direction){
        setDirection_native_Qt3DRender_QFrontFace_WindingDirection(QtJambi_LibraryUtilities.internal.nativeId(this), direction.value());
    }
    
    private native void setDirection_native_Qt3DRender_QFrontFace_WindingDirection(long __this__nativeId, int direction);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QFrontFace(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QFrontFace(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QFrontFace instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.9-sources.jar: io/qt/qt3d/render/QFrontFace.java <==
package io.qt.qt3d.render;


/**
 * <p>Defines front and back facing polygons</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html">Qt3DRender::QFrontFace</a></p>
 */
public class QFrontFace extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrontFace.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#WindingDirection-enum">Qt3DRender::QFrontFace::WindingDirection</a></p>
     */
    public enum WindingDirection implements io.qt.QtEnumerator {
        ClockWise(2304),
        CounterClockWise(2305);

        private WindingDirection(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static WindingDirection resolve(int value) {
            switch (value) {
            case 2304: return ClockWise;
            case 2305: return CounterClockWise;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#direction-prop">Qt3DRender::QFrontFace::directionChanged(Qt3DRender::QFrontFace::WindingDirection)</a></p>
     */
    @io.qt.QtPropertyNotify(name="direction")
    public final Signal1<io.qt.qt3d.render.QFrontFace.WindingDirection> directionChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QFrontFace(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrontFace() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#QFrontFace">Qt3DRender::QFrontFace::QFrontFace(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QFrontFace(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrontFace instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#direction-prop">Qt3DRender::QFrontFace::direction()const</a></p>
     */
    @io.qt.QtPropertyReader(name="direction")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QFrontFace.WindingDirection direction(){
        return io.qt.qt3d.render.QFrontFace.WindingDirection.resolve(direction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int direction_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfrontface.html#direction-prop">Qt3DRender::QFrontFace::setDirection(Qt3DRender::QFrontFace::WindingDirection)</a></p>
     */
    @io.qt.QtPropertyWriter(name="direction")
    public final void setDirection(io.qt.qt3d.render.QFrontFace.WindingDirection direction){
        setDirection_native_Qt3DRender_QFrontFace_WindingDirection(QtJambi_LibraryUtilities.internal.nativeId(this), direction.value());
    }
    
    private native void setDirection_native_Qt3DRender_QFrontFace_WindingDirection(long __this__nativeId, int direction);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QFrontFace(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QFrontFace(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QFrontFace instance, QDeclarativeConstructor constructor);
    
}
